import sys
import time
import glob
from datetime import datetime
from os import listdir, system

from flask import Flask, jsonify
from flask.ext.cors import CORS

DEVICE_FOLDER = "/sys/bus/w1/devices/"
DEVICE_SUFFIX = "/w1_slave"
WAIT_INTERVAL = 0.2

ALLOWABLE_ORIGINS = ["https://freeboard.io"]
system('modprobe w1-gpio')
system('modprobe w1-therm')

app = Flask(__name__)
cors_app = CORS(app, resources={r"/*": {"origins": ALLOWABLE_ORIGINS}})


@app.route("/")
def temperature():
    device = guess_temperature_sensor()
    print datetime.now(), "Request received"
    return jsonify(read_temperature(device))


def guess_temperature_sensor():
    """
    Try guessing the location of the installed temperature sensor
    """
    devices = listdir(DEVICE_FOLDER)
    devices = [device for device in devices if device.startswith('28-')]
    if devices:
        # print "Found", len(devices), "devices which maybe temperature sensors."
        return DEVICE_FOLDER + devices[0] + DEVICE_SUFFIX
    else:
        sys.exit("Sorry, no temperature sensors found")


def read_temperature(device):

    for sensor in glob.glob("/sys/bus/w1/devices/28-0114543d5daa/w1_slave"):
        id = sensor.split("/")[5]

        try:
            f = open(sensor, "r")
            data = f.read()
            f.close()
			if "YES" in data:
                (discard, sep, reading) = data.partition(' t=')
                temp1 = round(float(reading) / 1000.0, 1)
            else:
                temp1 = 999.9

        except:
            pass

    for sensor in glob.glob("/sys/bus/w1/devices/28-011453ebfdaa/w1_slave"):
        id = sensor.split("/")[5]

        try:
            f = open(sensor, "r")
            data = f.read()
            f.close()
            if "YES" in data:
                (discard, sep, reading) = data.partition(' t=')
                temp2 = round(float(reading) / 1000.0, 1)
            else:
                temp2 = 999.9

        except:
            pass
        
    print ("Temp1=",temp1, "Temp2=",temp2)
    
    response = {'temp1': temp1,
                'temp2': temp2}
    return response

if __name__ == "__main__":
    cors_app.run()